@@ -1,9 +1,9 @@
-from hooking.tight import wrap, on_enter, on_leave
+from hooking.tight import override, wrap, on_enter, on_leave
 from hooking.loose import H
 from hooking.context import Context
 from hooking.dto import HookInfo, TargetInfo
 from hooking.error import Error, ChainBreak
 from hooking.constant import ENTER, LEAVE
 
-__all__ = ["wrap", "on_enter", "on_leave", "ENTER", "LEAVE",
+__all__ = ["override", "wrap", "on_enter", "on_leave", "ENTER", "LEAVE",
            "H", "Context", "HookInfo", "TargetInfo", "ChainBreak", "Error"]
